==> aws-sdk-cpp-1.11.672-1-x86_64.pkg.tar.zst: usr/include/aws/forecast/ForecastServiceEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/forecast/ForecastService_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/forecast/ForecastServiceEndpointRules.h>


namespace Aws
{
namespace ForecastService
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using ForecastServiceClientContextParameters = Aws::Endpoint::ClientContextParameters;

using ForecastServiceClientConfiguration = Aws::Client::GenericClientConfiguration;
using ForecastServiceBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the ForecastService Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using ForecastServiceEndpointProviderBase =
    EndpointProviderBase<ForecastServiceClientConfiguration, ForecastServiceBuiltInParameters, ForecastServiceClientContextParameters>;

using ForecastServiceDefaultEpProviderBase =
    DefaultEndpointProvider<ForecastServiceClientConfiguration, ForecastServiceBuiltInParameters, ForecastServiceClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_FORECASTSERVICE_API ForecastServiceEndpointProvider : public ForecastServiceDefaultEpProviderBase
{
public:
    using ForecastServiceResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    ForecastServiceEndpointProvider()
      : ForecastServiceDefaultEpProviderBase(Aws::ForecastService::ForecastServiceEndpointRules::GetRulesBlob(), Aws::ForecastService::ForecastServiceEndpointRules::RulesBlobSize)
    {}

    ~ForecastServiceEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace ForecastService
} // namespace Aws

==> aws-sdk-cpp-1.11.744-1-x86_64.pkg.tar.zst: usr/include/aws/forecast/ForecastServiceEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/forecast/ForecastServiceEndpointRules.h>
#include <aws/forecast/ForecastService_EXPORTS.h>

namespace Aws {
namespace ForecastService {
namespace Endpoint {
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::DefaultEndpointProvider;
using Aws::Endpoint::EndpointProviderBase;

using ForecastServiceClientContextParameters = Aws::Endpoint::ClientContextParameters;

using ForecastServiceClientConfiguration = Aws::Client::GenericClientConfiguration;
using ForecastServiceBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the ForecastService Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using ForecastServiceEndpointProviderBase =
    EndpointProviderBase<ForecastServiceClientConfiguration, ForecastServiceBuiltInParameters, ForecastServiceClientContextParameters>;

using ForecastServiceDefaultEpProviderBase =
    DefaultEndpointProvider<ForecastServiceClientConfiguration, ForecastServiceBuiltInParameters, ForecastServiceClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_FORECASTSERVICE_API ForecastServiceEndpointProvider : public ForecastServiceDefaultEpProviderBase {
 public:
  using ForecastServiceResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

  ForecastServiceEndpointProvider()
      : ForecastServiceDefaultEpProviderBase(Aws::ForecastService::ForecastServiceEndpointRules::GetRulesBlob(),
                                             Aws::ForecastService::ForecastServiceEndpointRules::RulesBlobSize) {}

  ~ForecastServiceEndpointProvider() {}
};
}  // namespace Endpoint
}  // namespace ForecastService
}  // namespace Aws
